from setuptools import setup, find_packages
setup(
name='cmc-adb_utils',
version='0.1.0',
author='spektig',
author_email='ispektor92@gmail.com',
description='Multi ADB connection',
packages=find_packages(),
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: MIT License',
'Operating System :: OS Independent',
],
python_requires='>=3.10',
)
